@@ -3,7 +3,7 @@
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
 # Write by: liaojinqing@gbase.cn
-# Version : 1.3.11   update date: 2021-03-18
+# Version : 1.3.12   update date: 2021-12-02
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -111,11 +111,6 @@ if [ x"$SOFTPACKNAME" = x ]; then
   ENVCHECK=${ENVCHECK}" 1) Software not exists.\n"
 fi
 
-if [ -x "/sbin/ifconfig" -o -x "/usr/sbin/ifconfig" ]; then
-  loginfo "ifconfig check passed."
-else
-  ENVCHECK=${ENVCHECK}" 5) ifconfig not exists.\n" 
-fi
 if [ -x "/bin/unzip" -o -x "/usr/bin/unzip" ]; then
   loginfo "unzip check passed."
 else
@@ -138,7 +133,7 @@ if [ ! x"${ENVCHECK}" = x ]; then
 fi
 
 # IP use first IPADDR
-IPADDR=$(ifconfig -a | awk '/inet /{printf (split($2,a,":")>1)?a[2]:$2" "}')
+# IPADDR=$(ifconfig -a | awk '/inet /{printf (split($2,a,":")>1)?a[2]:$2" "}')
 loginfo "IPADDR: 0.0.0.0"
 loginfo "Datadir: $DATADIR"
 
@@ -265,6 +260,7 @@ export ${USER_UPPER}DIR=${INSTALL_DIR}
 export ${USER_UPPER}SERVER=${GBASESERVER}
 export ONCONFIG=onconfig.\$${USER_UPPER}SERVER
 export PATH=\$${USER_UPPER}DIR/bin:\${PATH}
+export ${USER_UPPER}SQLHOSTS=${INSTALL_DIR}/etc/sqlhosts
 
 export DB_LOCALE=${GBASELOCALE}
 export CLIENT_LOCALE=${GBASELOCALE}
@@ -298,7 +294,23 @@ chown ${USER_NAME}:${USER_NAME} $CFGFILE
 # datadir
 loginfo "Creating DATADIR: ${DATADIR} ."
 mkdir -p $DATADIR
+loginfo "Change permission for directory: $DATADIR ."
 chown ${USER_NAME}:${USER_NAME} $DATADIR
+
+DTDIR=$DATADIR
+while true
+do
+  DTTMP="${DTDIR%/*}"
+  DTDIR=$DTTMP
+  if [ x"${DTDIR}" = "x" ]; then
+    break
+  else
+    loginfo "Change permission for directory: $DTDIR ."
+    chmod 0755 $DTDIR
+  fi
+  sleep 1
+done
+
 TMPDIR=$(pwd)
 cd $DATADIR
 > rootchk
@@ -429,16 +441,17 @@ fi
 loginfo "Optimizing database config."
 sed -i "s#^PHYSBUFF.*#PHYSBUFF 1024#g" $CFGFILE
 sed -i "s#^LOGBUFF.*#LOGBUFF 1024#g" $CFGFILE
+sed -i "s#^DYNAMIC_LOGS.*#DYNAMIC_LOGS 0#g" $CFGFILE
+sed -i "s#^LTXHWM.*#LTXHWM 40#g" $CFGFILE
+sed -i "s#^LTXEHWM.*#LTXEHWM 50#g" $CFGFILE
 sed -i "s#^DBSPACETEMP.*#DBSPACETEMP tempdbs01#g" $CFGFILE
 sed -i "s#^SBSPACENAME.*#SBSPACENAME sbspace01#g" $CFGFILE
 sed -i "s#^SYSSBSPACENAME.*#SYSSBSPACENAME sbspace01#g" $CFGFILE
-# sed -i "s#^NUMFDSERVERS.*#NUMFDSERVERS 32#g" $CFGFILE
 sed -i "s#^MULTIPROCESSOR.*#MULTIPROCESSOR 1#g" $CFGFILE
 sed -i "s#^AUTO_TUNE.*#AUTO_TUNE 0#g" $CFGFILE
 sed -i "s#^CLEANERS.*#CLEANERS 32#g" $CFGFILE
 sed -i "s#^STACKSIZE.*#STACKSIZE 512#g" $CFGFILE
 sed -i "s#^ALLOW_NEWLINE.*#ALLOW_NEWLINE 1#g" $CFGFILE
-# sed -i 's#^USELASTCOMMITTED.*#USELASTCOMMITTED "COMMITTED READ"#g' $CFGFILE
 sed -i "s#^DS_MAX_QUERIES.*#DS_MAX_QUERIES 5#g" $CFGFILE
 sed -i "s#^DS_TOTAL_MEMORY.*#DS_TOTAL_MEMORY 1024000#g" $CFGFILE
 sed -i "s#^DS_NONPDQ_QUERY_MEM.*#DS_NONPDQ_QUERY_MEM 256000#g" $CFGFILE
@@ -461,7 +474,7 @@ sed -i "s#^SHMTOTAL.*#SHMTOTAL ${CFG_SHMTOTAL}#g" $CFGFILE
 
 sed -i "s#^BUFFERPOOL.*size=2.*#BUFFERPOOL size=2K,buffers=${CFG_2KPOOL},lrus=8,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
 if [ $NUMMEM -ge 8192 ]; then
-  sed -i "s#^BUFFERPOOL.*size=16.*#BUFFERPOOL size=16K,buffers=${CFG_16KPOOL},lrus=8,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
+  sed -i "s#^BUFFERPOOL.*size=16.*#BUFFERPOOL size=16K,buffers=${CFG_16KPOOL},lrus=64,lru_min_dirty=50,lru_max_dirty=60#g" $CFGFILE
 fi
 
 ####### restart database
@@ -491,7 +504,7 @@ cat <<EOF
 \$${USER_UPPER}DIR    : $INSTALL_DIR
 USER HOME       : $USER_HOME
 DBSPACE DIR     : $DATADIR
-IP ADDRESS      : $IPADDR
+IP ADDRESS      : ${IPADDR:-0.0.0.0}
 PORT NUMBER     : $PORTNO
 \$DB_LOCALE      : $GBASELOCALE
 \$CLIENT_LOCALE  : $GBASELOCALE
